@@ -15,8 +15,6 @@ ENVIRONMENT_VARIABLES = [
     "CI_JOB_MANUAL",
     "CI_JOB_NAME",
     "CI_JOB_STAGE",
-    "CI_JOB_TOKEN",
-    "CI_REPOSITORY_URL",
     "CI_RUNNER_DESCRIPTION",
     "CI_RUNNER_ID",
     "CI_RUNNER_TAGS",
@@ -30,7 +28,6 @@ ENVIRONMENT_VARIABLES = [
     "CI_PROJECT_URL",
     "CI_REGISTRY",
     "CI_REGISTRY_IMAGE",
-    "CI_REGISTRY_PASSWORD",
     "CI_REGISTRY_USER",
     "CI_SERVER",
     "CI_SERVER_NAME",
